==> apo-ws-client-6.00.50.1-sources.jar: fr/univlorraine/apowsclient/creationSE/ComposanteCGEDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ComposanteCGEDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ComposanteCGEDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codComposante"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="3"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codCGE"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="3"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="nbCapAcc" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ComposanteCGEDTO", namespace = "EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codComposante",
    "codCGE",
    "nbCapAcc"
})
public class ComposanteCGEDTO {

    @XmlElement(required = true, nillable = true)
    protected String codComposante;
    @XmlElement(required = true, nillable = true)
    protected String codCGE;
    @XmlElementRef(name = "nbCapAcc", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbCapAcc;

    /**
     * Obtient la valeur de la propriété codComposante.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodComposante() {
        return codComposante;
    }

    /**
     * Définit la valeur de la propriété codComposante.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodComposante(String value) {
        this.codComposante = value;
    }

    /**
     * Obtient la valeur de la propriété codCGE.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCGE() {
        return codCGE;
    }

    /**
     * Définit la valeur de la propriété codCGE.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCGE(String value) {
        this.codCGE = value;
    }

    /**
     * Obtient la valeur de la propriété nbCapAcc.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbCapAcc() {
        return nbCapAcc;
    }

    /**
     * Définit la valeur de la propriété nbCapAcc.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbCapAcc(JAXBElement<String> value) {
        this.nbCapAcc = value;
    }

}

==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/ComposanteCGEDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ComposanteCGEDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ComposanteCGEDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codComposante"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="3"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codCGE"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="3"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="nbCapAcc" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ComposanteCGEDTO", namespace = "EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codComposante",
    "codCGE",
    "nbCapAcc"
})
public class ComposanteCGEDTO {

    @XmlElement(required = true, nillable = true)
    protected String codComposante;
    @XmlElement(required = true, nillable = true)
    protected String codCGE;
    @XmlElement(nillable = true)
    protected String nbCapAcc;

    /**
     * Obtient la valeur de la propriété codComposante.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodComposante() {
        return codComposante;
    }

    /**
     * Définit la valeur de la propriété codComposante.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodComposante(String value) {
        this.codComposante = value;
    }

    /**
     * Obtient la valeur de la propriété codCGE.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCGE() {
        return codCGE;
    }

    /**
     * Définit la valeur de la propriété codCGE.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCGE(String value) {
        this.codCGE = value;
    }

    /**
     * Obtient la valeur de la propriété nbCapAcc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbCapAcc() {
        return nbCapAcc;
    }

    /**
     * Définit la valeur de la propriété nbCapAcc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbCapAcc(String value) {
        this.nbCapAcc = value;
    }

}
